# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ancv', 'ancv.data', 'ancv.data.models', 'ancv.visualization', 'ancv.web']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp[speedups]>=3.8.1,<4.0.0',
 'cachetools>=5.2.0,<6.0.0',
 'gidgethub>=5.1.0,<6.0.0',
 'humanize>=4.1.0,<5.0.0',
 'pydantic[email]>=1.9.1,<2.0.0',
 'rich>=12.4.4,<13.0.0',
 'structlog>=21.5.0,<22.0.0',
 'typer>=0.6.1,<0.7.0']

setup_kwargs = {
    'name': 'ancv',
    'version': '0.12.0',
    'description': "Render 'JSON Resume' sources to ANSI-enriched output for terminal clients (cURL, wget, ...) to consume.",
    'long_description': "# ancv\n\nGetting you [an CV](https://www.youtube.com/watch?v=mJUtMEJdvqM) (pronounced as *[ANSI](https://en.wikipedia.org/wiki/ANSI_escape_code)-v*) straight to your terminal.\n\nBe warned though, for this is kinda useless and just for fun:\n\n![Users Venn diagram](docs/images/users-venn.svg)\n\n## Getting started\n\n1. Create a resume according to the [JSON Resume Schema](https://jsonresume.org/schema/) (see also the [schema specification](https://github.com/jsonresume/resume-schema/blob/master/schema.json)) either:\n\n   - manually,\n   - exporting from LinkedIn using [Joshua Tzucker's LinkedIn exporter](https://joshuatz.com/projects/web-stuff/linkedin-profile-to-json-resume-exporter/) ([repo](https://github.com/joshuatz/linkedin-to-jsonresume)), or\n   - exporting from one of the platforms advertised as offering [JSON resume integration](https://jsonresume.org/schema/):\n     - <https://gitconnected.com/portfolio-api>\n     - <https://represent.io/>\n     - <https://www.doyoubuzz.com/us/>\n     - ...\n2. [Create a gist](https://gist.github.com/) named `resume.json` with those resume contents.\n   See [here](https://gist.github.com/thomasdavis/c9dcfa1b37dec07fb2ee7f36d7278105) for a working example from a [JSON Resume co-founder](https://github.com/orgs/jsonresume/people).\n3. Try it out, using...\n   - curl:\n\n      ```bash\n      curl -L ancv.io/username\n      ```\n\n      `-L` is shorthand for [`--location`](https://curl.se/docs/manpage.html), allowing you to follow the redirect from `http://ancv.io` through to `https://ancv.io`.\n      It's shorter than its also perfectly viable alternative:\n\n      ```bash\n      curl https://ancv.io/username\n      ```\n\n   - wget:\n\n     ```bash\n     wget -O - --quiet ancv.io/username\n     ```\n\n     where `-O` is short for [`--output-document`](https://linux.die.net/man/1/wget), used here to redirect to stdout.\n\n   - PowerShell (5 and 7):\n\n     ```powershell\n     (iwr ancv.io/username).Content\n     ```\n\n     where `iwr` is an alias for [`Invoke-Webrequest`](https://docs.microsoft.com/en-us/powershell/module/microsoft.powershell.utility/invoke-webrequest?view=powershell-7.2), returning an object.\n\n## Concept\n\n(put this as an SVG flowchart, left to right with conceptual sketches)\n\nSkeleton + Theme + Language + ASCII-mode toggle + Resume Data ==> terminal CV\n",
    'author': 'Alex Povel',
    'author_email': 'python@alexpovel.de',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://ancv.io',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
